@@ -3,7 +3,7 @@ package Specio::Constraint::Parameterizable;
 use strict;
 use warnings;
 
-our $VERSION = '0.43';
+our $VERSION = '0.48';
 
 use Carp qw( confess );
 use Role::Tiny::With;
@@ -116,7 +116,7 @@ Specio::Constraint::Parameterizable - A class which represents parameterizable c
 
 =head1 VERSION
 
-version 0.43
+version 0.48
 
 =head1 SYNOPSIS
 
@@ -147,11 +147,11 @@ This class's constructor accepts two additional parameters:
 This is a subroutine that generates a new constraint subroutine when the type
 is parameterized.
 
-It will be called as a method on the type and will be passed a single
-argument, the type object for the type parameter.
+It will be called as a method on the type and will be passed a single argument,
+the type object for the type parameter.
 
-This parameter is mutually exclusive with the
-C<parameterized_inline_generator> parameter.
+This parameter is mutually exclusive with the C<parameterized_inline_generator>
+parameter.
 
 =item * parameterized_inline_generator
 
@@ -159,9 +159,9 @@ This is a subroutine that generates a new inline generator subroutine when the
 type is parameterized.
 
 It will be called as a method on the L<Specio::Constraint::Parameterized>
-object when that object needs to generate an inline constraint. It will
-receive the type parameter as the first argument and the variable name as a
-string as the second.
+object when that object needs to generate an inline constraint. It will receive
+the type parameter as the first argument and the variable name as a string as
+the second.
 
 This probably seems fairly confusing, so looking at the examples in the
 L<Specio::Library::Builtins> code may be helpful.
@@ -176,8 +176,8 @@ C<parameterized_constraint_generator> parameter.
 This method takes two arguments. The C<of> argument should be an object which
 does the L<Specio::Constraint::Role::Interface> role, and is required.
 
-The other argument, C<declared_at>, is optional. If it is not given, then a
-new L<Specio::DeclaredAt> object is creating using a call stack depth of 1.
+The other argument, C<declared_at>, is optional. If it is not given, then a new
+L<Specio::DeclaredAt> object is creating using a call stack depth of 1.
 
 This method returns a new L<Specio::Constraint::Parameterized> object.
 
@@ -185,8 +185,6 @@ This method returns a new L<Specio::Constraint::Parameterized> object.
 
 Bugs may be submitted at L<https://github.com/houseabsolute/Specio/issues>.
 
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
-
 =head1 SOURCE
 
 The source code repository for Specio can be found at L<https://github.com/houseabsolute/Specio>.
@@ -197,7 +195,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 - 2018 by Dave Rolsky.
+This software is Copyright (c) 2012 - 2022 by Dave Rolsky.
 
 This is free software, licensed under:
 
